@@ -3263,27 +3263,44 @@ void KateViewInternal::clear()
 
 void KateViewInternal::wheelEvent(TQWheelEvent* e)
 {
-  if (m_lineScroll->minValue() != m_lineScroll->maxValue() && e->orientation() != Qt::Horizontal) {
-    // React to this as a vertical event
-    if ( ( e->state() & ControlButton ) || ( e->state() & ShiftButton ) ) {
-      if (e->delta() > 0)
-        scrollPrevPage();
-      else
-        scrollNextPage();
-    } else {
-      scrollViewLines(-((e->delta() / 120) * TQApplication::wheelScrollLines()));
-      // maybe a menu was opened or a bubbled window title is on us -> we shall erase it
-      update();
-      leftBorder->update();
-    }
+	if (e->state() & ControlButton)
+	{
+		if (e->delta() > 0)
+		{
+			slotIncFontSizes();
+		}
+		else
+		{
+			slotDecFontSizes();
+		}
+	}
+	else
+	{
+		if (m_lineScroll->minValue() != m_lineScroll->maxValue() && e->orientation() != Qt::Horizontal)
+		{
+			// React to this as a vertical event
+			if ( e->state() & ShiftButton )
+			{
+				if (e->delta() > 0)
+					scrollPrevPage();
+				else
+					scrollNextPage();
+			}
+			else
+			{
+				scrollViewLines(-((e->delta() / 120) * TQApplication::wheelScrollLines()));
+				// maybe a menu was opened or a bubbled window title is on us -> we shall erase it
+				update();
+				leftBorder->update();
+			}
+		} else if (columnScrollingPossible()) {
+			TQWheelEvent copy = *e;
+			TQApplication::sendEvent(m_columnScroll, &copy);
 
-  } else if (columnScrollingPossible()) {
-    TQWheelEvent copy = *e;
-    TQApplication::sendEvent(m_columnScroll, &copy);
-
-  } else {
-    e->ignore();
-  }
+		} else {
+			e->ignore();
+		}
+	}
 }
 
 void KateViewInternal::startDragScroll()
@@ -3492,5 +3509,3 @@ void KateViewInternal::imEndEvent( TQIMEvent *e )
   m_imPreeditSelStart = 0;
 }
 //END IM INPUT STUFF
-
-// kate: space-indent on; indent-width 2; replace-tabs on;
