@@ -747,7 +747,14 @@ public:
 
 		d = (x1 - x0) * (x1 - x0) + (y1 - y0) * (y1 - y0);
 
-		sfactor_sq = 1.0 / d - 0.25;
+		if (d)
+		{
+		  sfactor_sq = 1.0 / d - 0.25;
+		}
+		else
+		{
+		  sfactor_sq = 0;
+		}
 
 		if(sfactor_sq < 0)
 			sfactor_sq = 0;
@@ -770,7 +777,7 @@ public:
 		else if(th_arc > 0 && !sweepFlag)
 			th_arc -= 2 * M_PI;
 
-		n_segs = (int) (int) ceil(fabs(th_arc / (M_PI * 0.5 + 0.001)));
+		n_segs = (int) ceil(fabs(th_arc / (M_PI * 0.5 + 0.001)));
 
 		for(i = 0; i < n_segs; i++)
 		{
@@ -1736,17 +1743,34 @@ void KSVGIconPainter::drawPath(const TQString &data, bool filled)
 	double curx = 0.0, cury = 0.0, contrlx = 0.0, contrly = 0.0, xc, yc;
 	unsigned int lastCommand = 0;
 
-	TQString _d = value.replace(",", " ");
-	_d = _d.simplifyWhiteSpace();
-	const char *ptr = _d.latin1();
-	const char *end = _d.latin1() + _d.length() + 1;
+	TQCString _d = value.replace(",", " ").simplifyWhiteSpace().latin1();
+	const char *ptr = _d.data();
+	const char *end = _d.data() + _d.length();
 
 	double tox, toy, x1, y1, x2, y2, rx, ry, angle;
 	bool largeArc, sweep;
-	char command = *(ptr++);
+	char command = *ptr;
 
 	while(ptr < end)
 	{
+
+		if(*ptr == '+' || *ptr == '-' || *ptr == '.' || (*ptr >= '0' && *ptr <= '9'))
+		{
+			// there are still coords in this command
+			if(command == 'M')
+			{
+				command = 'L';
+			}
+			else if(command == 'm')
+			{
+				command = 'l';
+			}
+		}
+		else
+		{
+			command = *(ptr++);
+		}
+
 		if(*ptr == ' ')
 			ptr++;
 
@@ -2172,10 +2196,19 @@ void KSVGIconPainter::drawPath(const TQString &data, bool filled)
 				ptr = getCoord(ptr, rx);
 				ptr = getCoord(ptr, ry);
 				ptr = getCoord(ptr, angle);
-				ptr = getCoord(ptr, tox);
-				largeArc = tox == 1;
-				ptr = getCoord(ptr, tox);
-				sweep = tox == 1;
+				// 'largeArc' and 'sweep' are single digit flags. Some non conforming svg files do not
+				// separate those fields with separators, so we can't use getCoord() here.
+				// See TDE/tde issue #46 on TGW
+				largeArc = ((*ptr++) != '0');
+				while (*ptr == ' ')
+				{
+					ptr++;
+				}
+				sweep = ((*ptr++) != '0');
+				while (*ptr == ' ')
+				{
+					ptr++;
+				}
 				ptr = getCoord(ptr, tox);
 				ptr = getCoord(ptr, toy);
 
@@ -2191,10 +2224,19 @@ void KSVGIconPainter::drawPath(const TQString &data, bool filled)
 				ptr = getCoord(ptr, rx);
 				ptr = getCoord(ptr, ry);
 				ptr = getCoord(ptr, angle);
-				ptr = getCoord(ptr, tox);
-				largeArc = tox == 1;
-				ptr = getCoord(ptr, tox);
-				sweep = tox == 1;
+				// 'largeArc' and 'sweep' are single digit flags. Some non conforming svg files do not
+				// separate those fields with separators, so we can't use getCoord() here.
+				// See TDE/tde issue #46 on TGW
+				largeArc = ((*ptr++) != '0');
+				while (*ptr == ' ')
+				{
+					ptr++;
+				}
+				sweep = ((*ptr++) != '0');
+				while (*ptr == ' ')
+				{
+					ptr++;
+				}
 				ptr = getCoord(ptr, tox);
 				ptr = getCoord(ptr, toy);
 
@@ -2208,23 +2250,6 @@ void KSVGIconPainter::drawPath(const TQString &data, bool filled)
 				break;
 		}
 
-		if(*ptr == '+' || *ptr == '-' || *ptr == '.' || (*ptr >= '0' && *ptr <= '9'))
-		{
-			// there are still coords in this command
-			if(command == 'M')
-			{
-				command = 'L';
-			}
-			else if(command == 'm')
-			{
-				command = 'l';
-			}
-		}
-		else
-		{
-			command = *(ptr++);
-		}
-
 		// Detect reflection points
 		if(lastCommand != 'C' && lastCommand != 'c' &&
 			lastCommand != 'S' && lastCommand != 's' &&
