@@ -429,7 +429,7 @@ TQVariant TDEConfigBase::readPropertyEntry( const char *pKey,
       case TQVariant::ULongLong:
           return TQVariant( readUnsignedNum64Entry( pKey, aDefault.toULongLong() ) );
       case TQVariant::Bool:
-          return TQVariant( readBoolEntry( pKey, aDefault.toBool() ), 0 );
+          return TQVariant( readBoolEntry( pKey, aDefault.toBool() ) );
       case TQVariant::Double:
           return TQVariant( readDoubleNumEntry( pKey, aDefault.toDouble() ) );
       case TQVariant::DateTime:
