@@ -40,6 +40,13 @@
 /* TDENetworkSearchDomain                                                                         */
 /*================================================================================================*/
 
+extern "C" {
+	KDE_EXPORT TDEGlobalNetworkManager* create_tdeGlobalNetworkManager()
+	{
+		return new TDEGlobalNetworkManager();
+	}
+}
+
 TDENetworkSearchDomain::TDENetworkSearchDomain() {
 	m_isIPV6 = false;
 }
@@ -701,7 +708,7 @@ TDEWiFiConnection::~TDEWiFiConnection() {
 TDENetworkConnectionManager::TDENetworkConnectionManager(TDENetworkDevice *networkDevice) : TQObject(), m_connectionList(NULL), m_hwNeighborList(NULL), m_networkDevice(networkDevice), m_prevConnectionStatus(TDENetworkGlobalManagerFlags::Unknown) {
 	m_emissionTimer = new TQTimer();
 	connect(m_emissionTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(emitQueuedSignals()));
-	if (!m_emissionTimer->isActive()) m_emissionTimer->start(0, TRUE);
+	if (!m_emissionTimer->isActive()) m_emissionTimer->start(0, true);
 }
 
 TDENetworkConnectionManager::~TDENetworkConnectionManager() {
@@ -830,7 +837,7 @@ bool TDENetworkConnectionManager::validateIPAddress(TQHostAddress address) {
 
 bool TDENetworkConnectionManager::validateIPNeworkMask(TQHostAddress netmask) {
 	Q_UNUSED(netmask);
-	return TRUE;
+	return true;
 }
 
 void TDENetworkConnectionManager::clearTDENetworkConnectionList() {
@@ -855,7 +862,7 @@ void TDENetworkConnectionManager::internalNetworkConnectionStateChanged(TDENetwo
 	queuedEvent.newState = newState;
 	queuedEvent.previousState = m_prevConnectionStatus;
 	m_globalEventQueueEventList.append(queuedEvent);
-	if (!m_emissionTimer->isActive()) m_emissionTimer->start(0, TRUE);
+	if (!m_emissionTimer->isActive()) m_emissionTimer->start(0, true);
 
 	m_prevConnectionStatus = newState;
 }
@@ -871,7 +878,7 @@ void TDENetworkConnectionManager::internalNetworkDeviceStateChanged(TDENetworkCo
 	queuedEvent.previousConnStatus = m_prevDeviceStatus[deviceNodeName];
 	queuedEvent.deviceNode = deviceNodeName;
 	m_globalEventQueueEventList.append(queuedEvent);
-	if (!m_emissionTimer->isActive()) m_emissionTimer->start(0, TRUE);
+	if (!m_emissionTimer->isActive()) m_emissionTimer->start(0, true);
 
 	m_prevDeviceStatus[deviceNodeName] = newState;
 }
@@ -882,7 +889,7 @@ void TDENetworkConnectionManager::internalAccessPointStatusChanged(TDEMACAddress
 	queuedEvent.BSSID = BSSID;
 	queuedEvent.apevent = event;
 	m_globalEventQueueEventList.append(queuedEvent);
-	if (!m_emissionTimer->isActive()) m_emissionTimer->start(0, TRUE);
+	if (!m_emissionTimer->isActive()) m_emissionTimer->start(0, true);
 }
 
 void TDENetworkConnectionManager::internalNetworkDeviceEvent(TDENetworkDeviceEventType::TDENetworkDeviceEventType event, TQString message) {
@@ -891,7 +898,7 @@ void TDENetworkConnectionManager::internalNetworkDeviceEvent(TDENetworkDeviceEve
 	queuedEvent.ndevent = event;
 	queuedEvent.message = message;
 	m_globalEventQueueEventList.append(queuedEvent);
-	if (!m_emissionTimer->isActive()) m_emissionTimer->start(0, TRUE);
+	if (!m_emissionTimer->isActive()) m_emissionTimer->start(0, true);
 }
 
 void TDENetworkConnectionManager::internalVpnEvent(TDENetworkVPNEventType::TDENetworkVPNEventType event, TQString message) {
@@ -900,7 +907,7 @@ void TDENetworkConnectionManager::internalVpnEvent(TDENetworkVPNEventType::TDENe
 	queuedEvent.vpnevent = event;
 	queuedEvent.message = message;
 	m_globalEventQueueEventList.append(queuedEvent);
-	if (!m_emissionTimer->isActive()) m_emissionTimer->start(0, TRUE);
+	if (!m_emissionTimer->isActive()) m_emissionTimer->start(0, true);
 }
 
 void TDENetworkConnectionManager::internalNetworkManagementEvent(TDENetworkGlobalEventType::TDENetworkGlobalEventType event) {
@@ -908,7 +915,7 @@ void TDENetworkConnectionManager::internalNetworkManagementEvent(TDENetworkGloba
 	queuedEvent.eventType = 5;
 	queuedEvent.globalevent = event;
 	m_globalEventQueueEventList.append(queuedEvent);
-	if (!m_emissionTimer->isActive()) m_emissionTimer->start(0, TRUE);
+	if (!m_emissionTimer->isActive()) m_emissionTimer->start(0, true);
 }
 
 void TDENetworkConnectionManager::emitQueuedSignals() {
