@@ -862,7 +862,7 @@ bool KJSDebugWin::exception(ExecState *exec, const Value &value, bool inTryCatch
   if (dontShowAgain) {
     TDEConfig *config = kapp->config();
     TDEConfigGroupSaver saver(config,TQString::fromLatin1("Java/JavaScript Settings"));
-    config->writeEntry("ReportJavaScriptErrors",TQVariant(false,0));
+    config->writeEntry("ReportJavaScriptErrors",TQVariant(false));
     config->sync();
     TQByteArray data;
     kapp->dcopClient()->send( "konqueror*", "KonquerorIface", "reparseConfiguration()", data );
