@@ -224,7 +224,7 @@ void TDEHTMLPartBrowserExtension::copy()
 
         TQClipboard *cb = TQApplication::clipboard();
         disconnect( cb, TQT_SIGNAL( selectionChanged() ), m_part, TQT_SLOT( slotClearSelection() ) );
-#ifndef QT_NO_MIMECLIPBOARD
+#ifndef TQT_NO_MIMECLIPBOARD
 	TQString htmltext;
 	/*
 	 * When selectionModeEnabled, that means the user has just selected
@@ -333,7 +333,7 @@ void TDEHTMLPartBrowserExtension::updateEditActions()
     }
 
     // ### duplicated from KonqMainWindow::slotClipboardDataChanged
-#ifndef QT_NO_MIMECLIPBOARD // Handle minimalized versions of Qt Embedded
+#ifndef TQT_NO_MIMECLIPBOARD // Handle minimalized versions of Qt Embedded
     TQMimeSource *data = TQApplication::clipboard()->data();
     enableAction( "paste", data->provides( "text/plain" ) );
 #else
@@ -603,12 +603,12 @@ TDEHTMLPopupGUIClient::TDEHTMLPopupGUIClient( TDEHTMLPart *tdehtml, const TQStri
                  actionCollection(), "sendimage" );
 
 
-#ifndef QT_NO_MIMECLIPBOARD
+#ifndef TQT_NO_MIMECLIPBOARD
     (new TDEAction( i18n( "Copy Image" ), 0, this, TQT_SLOT( slotCopyImage() ),
                  actionCollection(), "copyimage" ))->setEnabled(!d->m_pixmap.isNull());
 #endif
 
-    if(d->m_pixmap.isNull()) {    //fallback to image location if still loading the image.  this will always be true if ifdef QT_NO_MIMECLIPBOARD
+    if(d->m_pixmap.isNull()) {    //fallback to image location if still loading the image.  this will always be true if ifdef TQT_NO_MIMECLIPBOARD
       new TDEAction( i18n( "Copy Image Location" ), 0, this, TQT_SLOT( slotCopyImageLocation() ),
                    actionCollection(), "copyimagelocation" );
     }
@@ -710,7 +710,7 @@ void TDEHTMLPopupGUIClient::slotCopyLinkLocation()
 {
   KURL safeURL(d->m_url);
   safeURL.setPass(TQString::null);
-#ifndef QT_NO_MIMECLIPBOARD
+#ifndef TQT_NO_MIMECLIPBOARD
   // Set it in both the mouse selection and in the clipboard
   KURL::List lst;
   lst.append( safeURL );
@@ -728,7 +728,7 @@ void TDEHTMLPopupGUIClient::slotStopAnimations()
 
 void TDEHTMLPopupGUIClient::slotCopyImage()
 {
-#ifndef QT_NO_MIMECLIPBOARD
+#ifndef TQT_NO_MIMECLIPBOARD
   KURL safeURL(d->m_imageURL);
   safeURL.setPass(TQString::null);
 
@@ -751,7 +751,7 @@ void TDEHTMLPopupGUIClient::slotCopyImageLocation()
 {
   KURL safeURL(d->m_imageURL);
   safeURL.setPass(TQString::null);
-#ifndef QT_NO_MIMECLIPBOARD
+#ifndef TQT_NO_MIMECLIPBOARD
   // Set it in both the mouse selection and in the clipboard
   KURL::List lst;
   lst.append( safeURL );
