@@ -203,7 +203,7 @@ protected:
     virtual void viewportMouseMoveEvent(TQMouseEvent *);
     virtual void viewportMouseReleaseEvent(TQMouseEvent *);
     virtual void viewportResizeEvent(TQResizeEvent*);
-#ifndef QT_NO_WHEELEVENT
+#ifndef TQT_NO_WHEELEVENT
     virtual void viewportWheelEvent(TQWheelEvent*);
 #endif
     virtual void dragEnterEvent( TQDragEnterEvent* );
@@ -220,7 +220,7 @@ protected:
 #ifndef NO_SMOOTH_SCROLL_HACK
     void startScrolling();
     void stopScrolling();
-#ifndef QT_NO_WHEELEVENT
+#ifndef TQT_NO_WHEELEVENT
     void scrollViewWheelEvent( TQWheelEvent* e );
 #endif
 #endif
