@@ -688,11 +688,10 @@ TDEIO_EXPORT TQByteArray TDEIO::rawErrorDetail(int errorCode, const TQString &er
       causes << i18n( "The requested protocol may not be supported." )
         << i18n( "The versions of the %1 protocol supported by this computer and "
         "the server may be incompatible." ).arg( protocol );
-      solutions << i18n( "You may perform a search on the Internet for a TDE "
-        "program (called a tdeioslave or ioslave) which supports this protocol. "
-        "Places to search include <a href=\"http://kde-apps.org/\">"
-        "http://kde-apps.org/</a> and <a href=\"http://freshmeat.net/\">"
-        "http://freshmeat.net/</a>." )
+      solutions << i18n( "You may perform a search on the Trinity website for a TDE "
+        "program (called a tdeioslave, ioslave or tdeio) which supports this protocol. "
+        "Places to search include <a href=\"https://mirror.git.trinitydesktop.org/cgit/\">"
+        "https://mirror.git.trinitydesktop.org/cgit/</a> or the repos for your distribution." )
         << sUpdate << sSysadmin;
       break;
 
@@ -1145,22 +1144,34 @@ TDEIO_EXPORT TQByteArray TDEIO::rawErrorDetail(int errorCode, const TQString &er
       break;
 
     case  TDEIO::ERR_SERVER_TIMEOUT:
+    {
+      int connTimeout   = KProtocolManager::connectTimeout();
+      int respTimeout   = KProtocolManager::responseTimeout();
+      int prConnTimeout = KProtocolManager::proxyConnectTimeout();
       errorName = i18n( "Timeout Error" );
-      description = i18n( "Although contact was made with the server, a "
-        "response was not received within the amount of time allocated for "
-        "the request as follows:<ul>"
-        "<li>Timeout for establishing a connection: %1 seconds</li>"
-        "<li>Timeout for receiving a response: %2 seconds</li>"
-        "<li>Timeout for accessing proxy servers: %3 seconds</li></ul>"
-        "Please note that you can alter these timeout settings in the TDE "
-        "Control Center, by selecting Network -> Preferences." )
-        .arg( KProtocolManager::connectTimeout() )
-        .arg( KProtocolManager::responseTimeout() )
-        .arg( KProtocolManager::proxyConnectTimeout() );
+      description = i18n("Although contact was made with the server, a "
+          "response was not received within the amount of time allocated for "
+          "the request as follows:")
+        .append(TQString::fromLatin1("<ul><li>"))
+        .append(i18n("Timeout for establishing a connection: %n second",
+                     "Timeout for establishing a connection: %n seconds",
+                     connTimeout))
+        .append(TQString::fromLatin1("</li><li>"))
+        .append(i18n("Timeout for receiving a response: %n second",
+                     "Timeout for receiving a response: %n seconds",
+                     respTimeout))
+        .append(TQString::fromLatin1("</li><li>"))
+        .append(i18n("Timeout for accessing proxy servers: %n second",
+                     "Timeout for accessing proxy servers: %n seconds",
+                     prConnTimeout))
+        .append(TQString::fromLatin1("</li></ul>"))
+        .append(i18n("Please note that you can alter these timeout settings in the TDE "
+                     "Control Center, by selecting Network -> Preferences." ));
       causes << cNetpath << i18n( "The server was too busy responding to other "
         "requests to respond." );
       solutions << sTryagain << sServeradmin;
       break;
+    }
 
     case  TDEIO::ERR_UNKNOWN:
       errorName = i18n( "Unknown Error" );
