@@ -593,7 +593,7 @@ TQVariant KService::property( const TQString& _name, TQVariant::Type t ) const
 
   // Then we use a homebuild class based on TDEConfigBase to convert the TQString.
   // For some often used property types we do the conversion ourselves.
-  TQMap<TQString,TQVariant>::ConstIterator it = m_mapProps.find( _name );
+  TQStringVariantMap::ConstIterator it = m_mapProps.find( _name );
   if ( (it == m_mapProps.end()) || (!it.data().isValid()))
   {
      //kdDebug(7012) << "Property not found " << _name << endl;
@@ -620,7 +620,7 @@ TQVariant KService::property( const TQString& _name, TQVariant::Type t ) const
            }
            if (t == TQVariant::Bool)
            {
-               return TQVariant((bool)val, 1);
+               return TQVariant((bool)val);
            }
            return TQVariant(val);
         }
@@ -635,7 +635,7 @@ TQStringList KService::propertyNames() const
 {
   TQStringList res;
 
-  TQMap<TQString,TQVariant>::ConstIterator it = m_mapProps.begin();
+  TQStringVariantMap::ConstIterator it = m_mapProps.begin();
   for( ; it != m_mapProps.end(); ++it )
     res.append( it.key() );
 
@@ -750,7 +750,7 @@ TQString KService::username() const {
 }
 
 bool KService::noDisplay() const {
-  TQMap<TQString,TQVariant>::ConstIterator it = m_mapProps.find( "NoDisplay" );
+  TQStringVariantMap::ConstIterator it = m_mapProps.find( "NoDisplay" );
   if ( (it != m_mapProps.end()) && (it.data().isValid()))
   {
      TQString aValue = it.data().toString().lower();
@@ -798,7 +798,7 @@ TQString KService::untranslatedGenericName() const {
 }
 
 bool KService::SuSEunimportant() const {
-  TQMap<TQString,TQVariant>::ConstIterator it = m_mapProps.find( "X-SuSE-Unimportant" );
+  TQStringVariantMap::ConstIterator it = m_mapProps.find( "X-SuSE-Unimportant" );
   if ( (it == m_mapProps.end()) || (!it.data().isValid()))
   {
      return false;
@@ -812,7 +812,7 @@ bool KService::SuSEunimportant() const {
 }
 
 TQString KService::parentApp() const {
-  TQMap<TQString,TQVariant>::ConstIterator it = m_mapProps.find( "X-TDE-ParentApp" );
+  TQStringVariantMap::ConstIterator it = m_mapProps.find( "X-TDE-ParentApp" );
   if ( (it == m_mapProps.end()) || (!it.data().isValid()))
   {
      return TQString::null;
