@@ -1645,11 +1645,16 @@ void FileProtocol::unmount( const TQString& _point )
 
        if (!udi.isEmpty())
            reply = d.call("unmount", udi);
-       
+
        if (udi.isEmpty() || !reply.isValid())
-         err = olderr;
-       else if (reply.isValid())
-         reply.get(err);
+           err = olderr;
+       else if (reply.isValid()) {
+           TQStringVariantMap unmountResult;
+           reply.get(unmountResult);
+           if (!unmountResult.contains("result") || !unmountResult["result"].toBool()) {
+               err = unmountResult.contains("errStr") ? unmountResult["errStr"].toString() : i18n("Unknown unmount error.");
+           }
+       }
     }
 
     if ( err.isEmpty() )
@@ -1666,19 +1671,17 @@ void FileProtocol::unmount( const TQString& _point )
 
 bool FileProtocol::pmount(const TQString &dev)
 {
-    TQString mountProg;
+    TQString mountProg = TQString::null;
     TQCString buffer;
 
 #ifdef WITH_UDISKS2
     // Use 'udisksctl' (UDISKS2) if available
-    if (mountProg.isEmpty()) {
-        mountProg = TDEGlobal::dirs()->findExe("udisksctl");
-        if (!mountProg.isEmpty()) {
-            buffer.sprintf( "%s mount -b %s", TQFile::encodeName(mountProg).data(),
-                        TQFile::encodeName(TDEProcess::quote(dev)).data() );
-        }
-    }
-#endif // WITH_UDISKS2
+		mountProg = TDEGlobal::dirs()->findExe("udisksctl");
+		if (!mountProg.isEmpty()) {
+				buffer.sprintf( "%s mount -b %s", TQFile::encodeName(mountProg).data(),
+										TQFile::encodeName(TDEProcess::quote(dev)).data() );
+		}
+#endif
 
 #ifdef WITH_UDISKS
     // Use 'udisks' (UDISKS1) if available
@@ -1689,7 +1692,7 @@ bool FileProtocol::pmount(const TQString &dev)
                         TQFile::encodeName(TDEProcess::quote(dev)).data() );
         }
     }
-#endif // WITH_UDISKS
+#endif
 
     // Use 'pmount', if available
     if (mountProg.isEmpty()) {
@@ -1733,19 +1736,17 @@ bool FileProtocol::pumount(const TQString &point)
     if (dev.isEmpty()) return false;
     if (dev.endsWith("/")) dev.truncate(dev.length()-1);
 
-    TQString umountProg;
+    TQString umountProg = TQString::null;
     TQCString buffer;
 
 #ifdef WITH_UDISKS2
     // Use 'udisksctl' (UDISKS2), if available
-    if (umountProg.isEmpty()) {
-        umountProg = TDEGlobal::dirs()->findExe("udisksctl");
-        if (!umountProg.isEmpty()) {
-            buffer.sprintf( "%s unmount -b %s", TQFile::encodeName(umountProg).data(),
-                    TQFile::encodeName(TDEProcess::quote(dev)).data() );
-        }
-    }
-#endif // WITH_UDISKS2
+		umountProg = TDEGlobal::dirs()->findExe("udisksctl");
+		if (!umountProg.isEmpty()) {
+				buffer.sprintf( "%s unmount -b %s", TQFile::encodeName(umountProg).data(),
+								TQFile::encodeName(TDEProcess::quote(dev)).data() );
+		}
+#endif
 
 #ifdef WITH_UDISKS
     // Use 'udisks' (UDISKS1), if available
@@ -1756,7 +1757,7 @@ bool FileProtocol::pumount(const TQString &point)
                     TQFile::encodeName(TDEProcess::quote(dev)).data() );
         }
     }
-#endif // WITH_UDISKS
+#endif
 
     // Use 'pumount', if available
     if (umountProg.isEmpty()) {
