@@ -737,7 +737,7 @@ case 5:
     break;}
 case 6:
 #line 51 "./fooparser.y"
-{ TQMap<TQString,TQVariant>::ConstIterator it = yyvsp[0].mapBegin(); yyvsp[-2].asMap().insert(it.key(), it.data()); yyval = yyvsp[-2]; ;
+{ TQStringVariantMap::ConstIterator it = yyvsp[0].mapBegin(); yyvsp[-2].asMap().insert(it.key(), it.data()); yyval = yyvsp[-2]; ;
     break;}
 case 7:
 #line 54 "./fooparser.y"
