@@ -499,13 +499,13 @@ KDE_EXPORT int KRsync::establishConnectionRsync(char *buffer, TDEIO::fileoffset_
                 myDebug( << "sending mpass" << endl);
                 connectionAuth.prompt = thisFn+buf;
                 connectionAuth.password = TQString(); // don't prefill
-                TQCString thispass;
+                TQString thispass;
                 if (KPasswordDialog::getPassword (thispass, i18n("Remote authorization required") + TQString("\n") + i18n("Please input") + TQString(" ") + TQString(buf), NULL) != 1) {
                     shutdownConnection(true, false);
                     return -1;
                 }
                 else {
-                    connectionAuth.password = TQString(thispass);
+                    connectionAuth.password = thispass;
                 }
                 connectionAuth.password += "\n";
                 myDebug( << "sending pass" << endl);
@@ -622,13 +622,13 @@ KDE_EXPORT int KRsync::establishConnectionUnison(char *buffer, TDEIO::fileoffset
                 myDebug( << "sending mpass" << endl);
                 connectionAuth.prompt = thisFn+buf;
                 connectionAuth.password = TQString(); // don't prefill
-                TQCString thispass;
+                TQString thispass;
                 if (KPasswordDialog::getPassword (thispass, i18n("Remote authorization required") + TQString("\n") + i18n("Please input") + TQString(" ") + TQString(buf), NULL) != 1) {
                     slotUnisonCancelled();
                     return -1;
                 }
                 else {
-                    connectionAuth.password = TQString(thispass);
+                    connectionAuth.password = thispass;
                 }
                 connectionAuth.password += "\n";
                 myDebug( << "sending pass" << endl);
