@@ -148,7 +148,7 @@ TDEPopupMenu* KHelpMenu::menu()
     {
       if (need_separator)
         mMenu->insertSeparator();
-      mMenu->insertItem( i18n( "&Report Bug/Request Enhancement..." ), menuReportBug );
+      mMenu->insertItem( SmallIcon("bug"), i18n( "&Report Bug/Request Enhancement..." ), menuReportBug );
       mMenu->connectItem( menuReportBug, this, TQT_SLOT(reportBug()) );
       need_separator = true;
     }
@@ -174,7 +174,7 @@ TDEPopupMenu* KHelpMenu::menu()
     
     if (kapp->authorizeTDEAction("help_about_kde"))
     {
-      mMenu->insertItem( SmallIcon("about_kde"), i18n( "About &Trinity" ), menuAboutKDE );
+      mMenu->insertItem( SmallIcon("about_kde"), i18n( "About &TDE" ), menuAboutKDE );
       mMenu->connectItem( menuAboutKDE, this, TQT_SLOT( aboutKDE() ) );
     }
   }
