@@ -75,10 +75,9 @@ public:
     ~KPasswordEdit();
 
     /**
-     * Returns the password. The memory is freed in the destructor
-     * so you should make a copy.
+     * Returns the password.
      */
-    const char *password() const;
+    TQString password() const;
 
     /**
      * Erases the current password.
@@ -128,7 +127,7 @@ private:
  * <b>Usage example</b>\n
  *
  * \code
- * TQCString password;
+ * TQString password;
  * int result = KPasswordDialog::getPassword(password, i18n("Prompt message"));
  * if (result == KPasswordDialog::Accepted)
  *     use(password);
@@ -145,14 +144,6 @@ private:
  * Core dumps are dangerous because they are an image of the process memory,
  * and thus include any passwords that were in memory.
  *
- * @li You should delete passwords as soon as they are not needed anymore.
- * The functions getPassword() and getNewPassword() return the
- * password as a TQCString. I believe this is safer than a TQString. A QString
- * stores its characters internally as 16-bit wide values, so conversions are
- * needed, both for creating the TQString and by using it. The temporary
- * memory used for these conversion is probably not erased. This could lead
- * to stray  passwords in memory, even if you think you erased all of them.
- *
  * @author Geert Jansen <jansen@kde.org>
  */
 
@@ -326,10 +317,9 @@ public:
     int passwordStrengthWarningLevel() const;
 
     /**
-     * Returns the password entered. The memory is freed in the destructor,
-     * so you should make a copy.
+     * Returns the password entered.
      */
-    const char *password() const { return m_pEdit->password(); }
+    TQString password() const { return m_pEdit->password(); }
 
     /**
      * Clears the password input field. You might want to use this after the
@@ -355,7 +345,7 @@ public:
      * is shown and the result is stored in *keep.
      * @return Result code: Accepted or Rejected.
      */
-    static int getPassword(TQCString &password, TQString prompt, int *keep=0L);
+    static int getPassword(TQString &password, TQString prompt, int *keep=0L);
 
     /**
      * Pops up the dialog, asks the user for a password and returns it. The
@@ -367,7 +357,7 @@ public:
      * information. The text is word broken to fit nicely in the dialog.
      * @return Result code: Accepted or Rejected.
      */
-    static int getNewPassword(TQCString &password, TQString prompt);
+    static int getNewPassword(TQString &password, TQString prompt);
 
     /**
      * Static helper function that disables core dumps.
@@ -387,7 +377,7 @@ protected:
      * checking in derived classes. It should return @p true if the
      * password is valid, @p false otherwise.
      */
-    virtual bool checkPassword(const char *) { return true; }
+    virtual bool checkPassword(const TQString&) { return true; }
 
 private slots:
   void enableOkBtn();
